@@ -225,7 +225,7 @@ def delete(file_path, **kwargs):
     min_thread_threshold = obj.get_kwarg(["min thread threshold", "min files thread"], 100, (int), **kwargs)
 
     file_list = _gen_path_list(file_path)
-    print("file_list: ", json.dumps(file_list, indent=4))
+    # print("file_list: ", json.dumps(file_list, indent=4))
     # exit()
     if len(file_list) > 0:
         if threading is True and len(file_list) >= min_thread_threshold and ftp is None:
@@ -237,7 +237,7 @@ def delete(file_path, **kwargs):
                 if 'file_path' in file:
                     _delete_single_file(file['file_path'], shred, ftp)
             if isinstance(file, (str)):
-                print(f"_delete_single_file")
+                # print(f"_delete_single_file")
                 _delete_single_file(file, shred, ftp)
     return True
 
